Changelog
=========

v0.3.1
------

- Added validation for URL strings in constructing the tags.

v0.3.0
------

- Added classes for building some of the tags:

  - <h1></h1>
  - <h2></h2>
  - <h3></h3>
  - <h4></h4>
  - <h5></h5>
  - <h6></h6>
  - <head></head>
  - <header></header>
  - <hr>

Caveats:

- Korona has no ability to construct inner tags for now. (For ex. <address><p>Hi There</p></address>)
- Korona will be added with constructing the inner tags in the future releases.

v0.2.0
------

- Added classes for building some of the tags:

  - <colgroup></colgroup>
  - <dd></dd>
  - <del></del>
  - <details></details>
  - <dialog></dialog>
  - <div></div>
  - <dl></dl>
  - <dt></dt>
  - <embed>
  - <fieldset></fieldset>
  - <figure></figure>
  - <footer></footer>
  - <form></form>
  - <frame>
  - <frameset></frameset>

Caveats:

- Korona has no ability to construct inner tags for now. (For ex. <address><p>Hi There</p></address>)
- Korona will be added with constructing the inner tags in the future releases.

v0.1.0
------

- First release.
- Added classes for building some of the tags:

  - <a></a>
  - <abbr></abbr>
  - <acronym></acronym>
  - <address></address>
  - <area>
  - <article></article>
  - <b></b>
  - <base>
  - <button></button>
  - <canvas></canvas>
  - <caption></caption>
  - <cite></cite>

Caveats:

- Korona has no ability to construct inner tags for now. (For ex. <address><p>Hi There</p></address>)
- Korona will be added with constructing the inner tags in the future releases.
